==> eam-wshub-proxyclient-11.5-13-sources.jar: net/datastream/schemas/mp_fields/REPORTFILTERID.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUNCTIONCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FILTERCODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "usercode",
    "functioncode",
    "filtercode"
})
@XmlRootElement(name = "REPORTFILTERID")
public class REPORTFILTERID {

    @XmlElement(name = "USERCODE", required = true)
    protected String usercode;
    @XmlElement(name = "FUNCTIONCODE", required = true)
    protected String functioncode;
    @XmlElement(name = "FILTERCODE", required = true)
    protected String filtercode;

    /**
     * Obtient la valeur de la propriété usercode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERCODE() {
        return usercode;
    }

    /**
     * Définit la valeur de la propriété usercode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERCODE(String value) {
        this.usercode = value;
    }

    /**
     * Obtient la valeur de la propriété functioncode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFUNCTIONCODE() {
        return functioncode;
    }

    /**
     * Définit la valeur de la propriété functioncode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFUNCTIONCODE(String value) {
        this.functioncode = value;
    }

    /**
     * Obtient la valeur de la propriété filtercode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFILTERCODE() {
        return filtercode;
    }

    /**
     * Définit la valeur de la propriété filtercode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFILTERCODE(String value) {
        this.filtercode = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/REPORTFILTERID.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUNCTIONCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FILTERCODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "usercode",
    "functioncode",
    "filtercode"
})
@XmlRootElement(name = "REPORTFILTERID")
public class REPORTFILTERID {

    @XmlElement(name = "USERCODE", required = true)
    protected String usercode;
    @XmlElement(name = "FUNCTIONCODE", required = true)
    protected String functioncode;
    @XmlElement(name = "FILTERCODE", required = true)
    protected String filtercode;

    /**
     * Gets the value of the usercode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERCODE() {
        return usercode;
    }

    /**
     * Sets the value of the usercode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERCODE(String value) {
        this.usercode = value;
    }

    /**
     * Gets the value of the functioncode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFUNCTIONCODE() {
        return functioncode;
    }

    /**
     * Sets the value of the functioncode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFUNCTIONCODE(String value) {
        this.functioncode = value;
    }

    /**
     * Gets the value of the filtercode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFILTERCODE() {
        return filtercode;
    }

    /**
     * Sets the value of the filtercode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFILTERCODE(String value) {
        this.filtercode = value;
    }

}
